@@ -5,7 +5,15 @@ import flake8
 ATTRIBUTE_PROPERTY = '_flake8-type-checking__parent'
 ANNOTATION_PROPERTY = '_flake8-type-checking__is_annotation'
 
-ATTRS_DECORATORS = ['attrs.define', 'attr.define', 'attr.s']
+ATTRS_DECORATORS = [
+    'attrs.define',
+    'attrs.frozen',
+    'attrs.mutable',
+    'attr.define',
+    'attr.frozen',
+    'attr.mutable',
+    'attr.s',
+]
 ATTRS_IMPORTS = {'attrs', 'attr'}
 
 py38 = sys.version_info.major == 3 and sys.version_info.minor == 8
